###########################################
Q-Transform (:mod:`gwpy.signal.qtransform`)
###########################################

.. automodule:: gwpy.signal.qtransform

.. seealso::

    - **Examples**: :doc:`/examples/timeseries/qscan`

.. automodapi:: gwpy.signal.qtransform
    :include-all-objects:
    :no-heading:
    :no-main-docstr:
